@@ -80,7 +80,12 @@ typedef signed long long int64;
 #endif
 void CLIB_DECL D_(const char *text, ...) ATTR_PRINTF(1,2);
 #else
+// VS prior to VC7.1 does not support variadic macros. VC8.0 does not optimize unused parameters passing
+#if _MSC_VER < 1400
 void __inline CLIB_DECL D_(const char *text, ...) { do {} while (0); }
+#else
+#define D_(args, ...) do {} while (0)
+#endif
 #endif
 
 #elif defined ANDROID
@@ -125,6 +130,7 @@ void __inline CLIB_DECL D_(const char *text, ...) { do {} while (0); }
 #define dup _dup
 #define fileno _fileno
 #define snprintf _snprintf
+#define vsnprintf _vsnprintf
 #define strnicmp _strnicmp
 #define strdup _strdup
 #define fdopen _fdopen
@@ -153,19 +159,23 @@ void __inline CLIB_DECL D_(const char *text, ...) { do {} while (0); }
 #define QUIRK_FILTER	(1 << 16)	/* Enable filter */
 #define QUIRK_IGSTPOR	(1 << 17)	/* Ignore stray tone portamento */
 #define QUIRK_KEYOFF	(1 << 18)	/* Keyoff doesn't reset fadeout */
-#define QUIRK_DEEPVIB	(1 << 19)	/* Vibrato is twice as deep */
+#define QUIRK_VIBHALF	(1 << 19)	/* Vibrato is half as deep */
 #define QUIRK_VIBALL	(1 << 20)	/* Vibrato in all frames */
-#define QUIRK_PRENV	(1 << 21)	/* Portamento resets envelope & fade */
+#define QUIRK_VIBINV	(1 << 21)	/* Vibrato has inverse waveform */
+#define QUIRK_PRENV	(1 << 22)	/* Portamento resets envelope & fade */
+#define QUIRK_S3MLFO	(1 << 23)	/* S3M-style LFO waveforms */
 
 #define HAS_QUIRK(x)	(m->quirk & (x))
 
 
 /* Format quirks */
-#define QUIRKS_ST3		(QUIRK_S3MLOOP | QUIRK_VOLPDN | QUIRK_FINEFX)
+#define QUIRKS_ST3		(QUIRK_S3MLOOP | QUIRK_VOLPDN | QUIRK_FINEFX | \
+				 QUIRK_S3MLFO  )
 #define QUIRKS_FT2		(QUIRK_FINEFX)
 #define QUIRKS_IT		(QUIRK_S3MLOOP | QUIRK_FINEFX | QUIRK_VIBALL | \
 				 QUIRK_ENVFADE | QUIRK_ITVPOR | QUIRK_KEYOFF | \
-				 QUIRK_VIRTUAL | QUIRK_FILTER | QUIRK_IGSTPOR)
+				 QUIRK_VIRTUAL | QUIRK_FILTER | QUIRK_S3MLFO | \
+				 QUIRK_IGSTPOR )
 
 /* DSP effects */
 #define DSP_EFFECT_CUTOFF	0x02
