@@ -43,11 +43,8 @@ static int read_file_header(FILE *in, struct archived_file_header_tag *hdrp)
 	start = read32l(in);
 	ver = read32l(in);
 
-	//report("v%d.%02d/", ver / 100, ver % 100);
-
 	read32l(in);
 	ver = read32l(in);
-	//report("%d... ", ver);
 
 	fseek(in, 68, SEEK_CUR);		/* reserved */
 
@@ -67,11 +64,6 @@ static int read_file_header(FILE *in, struct archived_file_header_tag *hdrp)
 		hdrp->compressed_size = read32l(in);
 		hdrp->offset = read32l(in);
 
-		//printf("method = %d\n", hdrp->method);
-		//printf("name = %s\n", hdrp->name);
-		//printf("orig_size = %d\n", hdrp->orig_size);
-		//printf("compressed_size = %d\n", hdrp->compressed_size);
-
 		if (x == 1)			/* deleted */
 			continue;
 
@@ -83,19 +75,6 @@ static int read_file_header(FILE *in, struct archived_file_header_tag *hdrp)
 		hdrp->offset &= 0x7fffffff;	
 		hdrp->offset += start;	
 
-		//printf("crc = 0x%04x\n", hdrp->crc);
-		//printf("bits = %d\n", hdrp->bits);
-		//printf("offset = %d\n", hdrp->offset);
-
-#if 0
-		/* We don't files named 'From?' */
-		while (!strcmp(hdr.name, "From?") || *hdr.name == '!') {
-			if (!skip_file_data(in,&hdr))
-				return -1;
-			if (!read_file_header(in, &hdr))
-				return -1;
-		}
-#endif
 		break;
 	}
 
@@ -128,33 +107,20 @@ static unsigned char *read_file_data(FILE *in,
 static int arcfs_extract(FILE *in, FILE *out)
 {
 	struct archived_file_header_tag hdr;
-	/* int done = 0; */
 	unsigned char *data, *orig_data;
 	int exitval = 0;
-	int supported;
 
 	if (!read_file_header(in, &hdr))
 		return -1;
 
-	if (hdr.method == 0) {	/* EOF */
-		/* done = 1;
-		continue; */
+	if (hdr.method == 0)
 		return -1;
-	}
 
-	if ((data = read_file_data(in, &hdr)) == NULL) {
-		fprintf(stderr, "ArcFS: error reading data (hit EOF)\n");
+	/* error reading data (hit EOF) */
+	if ((data = read_file_data(in, &hdr)) == NULL)
 		return -1;
-	}
-
-#if 0
-out = fopen("data.out", "w");
-fwrite(data, 1, hdr.compressed_size, out);
-fclose(out);
-#endif
 
 	orig_data = NULL;
-	supported = 0;
 
 	/* FWIW, most common types are (by far) 8/9 and 2.
 	 * (127 is the most common in Spark archives, but only those.)
@@ -162,83 +128,42 @@ fclose(out);
 	 * And I don't think I've seen a *single* file with 1 or 7 yet.
 	 */
 	switch (hdr.method) {
-	case 1:
 	case 2:		/* no compression */
-		supported = 1;
 		orig_data = data;
 		break;
 
-	case 3:		/* "packed" (RLE) */
-		supported = 1;
-		orig_data =
-		    convert_rle(data, hdr.compressed_size, hdr.orig_size);
-		break;
-
-	case 4:		/* "squeezed" (Huffman, like CP/M `SQ') */
-		supported = 1;
-		orig_data =
-		    convert_huff(data, hdr.compressed_size, hdr.orig_size);
-		break;
-
-	case 5:		/* "crunched" (12-bit static LZW) */
-		supported = 1;
-		orig_data = convert_lzw_dynamic(data, 0, 0,
-					hdr.compressed_size, hdr.orig_size, 0);
-		break;
-
-	case 6:		/* "crunched" (RLE+12-bit static LZW) */
-		supported = 1;
-		orig_data = convert_lzw_dynamic(data, 0, 1,
-					hdr.compressed_size, hdr.orig_size, 0);
-		break;
-
-	case 7:	/* PKPAK docs call this one "internal to SEA" */
-		/* it looks like this one was only used by a development version
-		 * of SEA ARC, so chances are it can be safely ignored.
-		 * OTOH, it's just method 6 with a slightly different hash,
-		 * so I presume it wouldn't be *that* hard to add... :-)
-		 */
-		break;
-
 	case 8:		/* "Crunched" [sic]
 			 * (RLE+9-to-12-bit dynamic LZW, a *bit* like GIF) */
-		supported = 1;
 		orig_data = convert_lzw_dynamic(data, hdr.bits, 1,
 					hdr.compressed_size, hdr.orig_size, 0);
 		break;
 
 	case 9:		/* "Squashed" (9-to-13-bit, no RLE) */
-		supported = 1;
 		orig_data = convert_lzw_dynamic(data, hdr.bits, 0,
 					hdr.compressed_size, hdr.orig_size, 0);
 		break;
 
 	case 127:	/* "Compress" (9-to-16-bit, no RLE) ("Spark" only) */
-		supported = 1;
 		orig_data = convert_lzw_dynamic(data, hdr.bits, 0,
 					hdr.compressed_size, hdr.orig_size, 0);
 		break;
+
+	default:
+		free(data);
+		return -1;
 	}
 
 	if (orig_data == NULL) {
-		fprintf(stderr, "ArcFS: error extracting file\n");
-		exitval = 1;
-	} else {
-		char *ptr;
-
-		/* CP/M stuff in particular likes those slashes... */
-		while ((ptr = strchr(hdr.name, '/')) != NULL)
-			*ptr = '_';
-
-		if (fwrite(orig_data, 1, hdr.orig_size, out) != hdr.orig_size) {
-			fprintf(stderr, "error, %s\n", strerror(errno));
-			exitval = 1;
-		}
-
-		if (orig_data != data)	/* don't free uncompressed stuff twice :-) */
-			free(orig_data);
+		free(data);
+		return -1;
 	}
 
+	if (fwrite(orig_data, 1, hdr.orig_size, out) != hdr.orig_size)
+		exitval = -1;
+
+	if (orig_data != data)	/* don't free uncompressed stuff twice :-) */
+		free(orig_data);
+
 	free(data);
 
 	return exitval;
