@@ -3,6 +3,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <stddef.h>
 
 #define HIO_HANDLE_TYPE(x) ((x)->type)
 
@@ -11,10 +12,9 @@ typedef struct {
 #define HIO_HANDLE_TYPE_MEMORY	1
 	int type;
 	FILE *f;
-	uint8 *p;
 	uint8 *start;
-	long size;
-	int eof;
+	ptrdiff_t pos;
+	ptrdiff_t size;
 } HIO_HANDLE;
 
 int8	hio_read8s	(HIO_HANDLE *);
@@ -25,7 +25,7 @@ uint32	hio_read24l	(HIO_HANDLE *);
 uint32	hio_read24b	(HIO_HANDLE *);
 uint32	hio_read32l	(HIO_HANDLE *);
 uint32	hio_read32b	(HIO_HANDLE *);
-int	hio_read	(void *, int, int, HIO_HANDLE *);	
+size_t	hio_read	(void *, size_t, size_t, HIO_HANDLE *);	
 int	hio_seek	(HIO_HANDLE *, long, int);
 long	hio_tell	(HIO_HANDLE *);
 int	hio_eof		(HIO_HANDLE *);
