@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -23,7 +23,7 @@ static int amf_test(HIO_HANDLE *, char *, const int);
 static int amf_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader amf_loader = {
-	"DSMI Advanced Module Format (AMF)",
+	"DSMI Advanced Module Format",
 	amf_test,
 	amf_load
 };
@@ -135,7 +135,7 @@ static int amf_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	 */
 	if (ver <= 0x0a) {
 		uint8 b;
-		int len, start, end;
+		uint32 len, start, end;
 		long pos = hio_tell(f);
 		for (i = 0; i < mod->ins; i++) {
 			b = hio_read8(f);
@@ -253,7 +253,7 @@ static int amf_load(struct module_data *m, HIO_HANDLE *f, const int start)
 			/* Use empty track if an invalid track is requested
 			 * (such as in Lasse Makkonen "faster and louder")
 			 */
-			if (k < 0 || k > mod->trk)
+			if (k < 0 || k >= mod->trk)
 				k = 0;
 			mod->xxp[i]->index[j] = trkmap[k];
 /*printf("mod->xxp[%d]->info[%d].index = %d (k = %d)\n", i, j, trkmap[k], k);*/
