@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -19,7 +19,7 @@ static int dt_test(HIO_HANDLE *, char *, const int);
 static int dt_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader dt_loader = {
-	"Digital Tracker (DTM)",
+	"Digital Tracker",
 	dt_test,
 	dt_load
 };
@@ -248,7 +248,7 @@ static int dt_load(struct module_data *m, HIO_HANDLE *f, const int start)
 {
 	iff_handle handle;
 	struct local_data data;
-	int ret;
+	int ret, i;
 
 	LOAD_INIT();
 
@@ -270,12 +270,16 @@ static int dt_load(struct module_data *m, HIO_HANDLE *f, const int start)
 		return -1;
 
 	/* Load IFF chunks */
-	if (iff_load(handle, m, f , &data) < 0) {
-		iff_release(handle);
-		return -1;
-	}
-
+	ret = iff_load(handle, m, f , &data);
 	iff_release(handle);
+	if (ret < 0)
+		return -1;
+
+	//fix rest patterns
+	for (i = data.last_pat; i < m->mod.pat; i++) {
+		if (pattern_tracks_alloc(&m->mod, i, 64) < 0)
+			return -1;
+	}
 
 	return 0;
 }
