@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -17,7 +17,7 @@ static int fnk_test (HIO_HANDLE *, char *, const int);
 static int fnk_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader fnk_loader = {
-    "Funktracker (FNK)",
+    "Funktracker",
     fnk_test,
     fnk_load
 };
@@ -46,11 +46,9 @@ static int fnk_test(HIO_HANDLE *f, char *t, const int start)
     if (size < 1024)
 	return -1;
 
-    if (HIO_HANDLE_TYPE(f) == HIO_HANDLE_TYPE_FILE) {
-        hio_stat(f, &st);
-        if (size != st.st_size)
-            return -1;
-    }
+    hio_stat(f, &st);
+    if (size != st.st_size)
+        return -1;
 
     read_title(f, t, 0);
 
