@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -18,7 +18,7 @@ static int ice_test (HIO_HANDLE *, char *, const int);
 static int ice_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader ice_loader = {
-    "Soundtracker 2.6/Ice Tracker (MTN)",
+    "Soundtracker 2.6/Ice Tracker",
     ice_test,
     ice_load
 };
