@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -92,7 +92,7 @@ static int imf_test (HIO_HANDLE *, char *, const int);
 static int imf_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader imf_loader = {
-    "Imago Orpheus (IMF)",
+    "Imago Orpheus v1.0",
     imf_test,
     imf_load
 };
