@@ -1,16 +1,27 @@
-/* Extended Module Player
+/* Extended Module Player format loaders
  * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * This file is part of the Extended Module Player and is distributed
- * under the terms of the GNU Lesser General Public License. See COPYING.LIB
- * for more information.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /* Note: envelope switching (effect 9) and sample status change (effect 8)
- * are not supported. Frequency envelopes will be added in xmp 1.2.0. In
- * MDL envelopes are defined for each instrument in a patch -- xmp accepts
- * only one envelope for each patch, and the enveope of the first instrument
- * will be taken.
+ * not supported.
  */
 
 #include "loader.h"
@@ -36,7 +47,7 @@ static int mdl_test(HIO_HANDLE *f, char *t, const int start)
     if (hio_read32b(f) != MAGIC_DMDL)
 	return -1;
 
-    hio_read8(f);			/* version */
+    hio_read8(f);		/* version */
     id = hio_read16b(f);
 
     if (id == 0x494e) {		/* IN */
@@ -85,27 +96,31 @@ struct local_data {
 static void fix_env(int i, struct xmp_envelope *ei, struct mdl_envelope *env,
 		    int *index, int envnum)
 {
-    int j, k;
+    int j, k, lastx;
 
     if (index[i] >= 0) {
 	ei->flg = XMP_ENVELOPE_ON;
 	ei->npt = 16;
 
 	for (j = 0; j < envnum; j++) {
-    	    if (index[i] == j) {
+    	    if (index[i] == env[j].num) {
     	        ei->flg |= env[j].sus & 0x10 ? XMP_ENVELOPE_SUS : 0;
     	        ei->flg |= env[j].sus & 0x20 ? XMP_ENVELOPE_LOOP : 0;
     	        ei->sus = env[j].sus & 0x0f;
     	        ei->lps = env[j].loop & 0x0f;
     	        ei->lpe = env[j].loop & 0xf0;
-    	        ei->data[0] = 0;
 
-    	        for (k = 1; k < ei->npt; k++) {
-        	    ei->data[k * 2] = ei->data[(k - 1) * 2] +
-        				env[j].data[(k - 1) * 2];
-        	    if (env[j].data[k * 2] == 0)
+		lastx = -1;
+
+    	        for (k = 0; k < ei->npt; k++) {
+		    int x = env[j].data[k * 2];
+
+        	    if (x == 0)
         		    break;
-        	    ei->data[k * 2 + 1] = env[j].data[(k - 1) * 2 + 1];
+        	    ei->data[k * 2] = lastx + x;
+        	    ei->data[k * 2 + 1] = env[j].data[k * 2 + 1];
+
+		    lastx = ei->data[k * 2];
         	}
 
         	ei->npt = k;
@@ -123,9 +138,6 @@ static void fix_env(int i, struct xmp_envelope *ei, struct mdl_envelope *env,
 static void xlat_fx_common(uint8 *t, uint8 *p)
 {
     switch (*t) {
-    case 0x00:			/* - - No effect */
-	*p = 0;
-	break;
     case 0x07:			/* 7 - Set BPM */
 	*t = FX_S3M_BPM;
 	break;
@@ -165,6 +177,9 @@ static void xlat_fx_common(uint8 *t, uint8 *p)
 static void xlat_fx1(uint8 *t, uint8 *p)
 {
     switch (*t) {
+    case 0x00:			/* - - No effect */
+	*p = 0;
+	break;
     case 0x05:			/* 5 - Arpeggio */
 	*t = FX_ARPEGGIO;
 	break;
@@ -180,6 +195,9 @@ static void xlat_fx1(uint8 *t, uint8 *p)
 static void xlat_fx2(uint8 *t, uint8 *p)
 {
     switch (*t) {
+    case 0x00:			/* - - No effect */
+	*p = 0;
+	break;
     case 0x01:			/* G - Volume slide up */
 	*t = FX_VOLSLIDE_UP;
 	break;
@@ -363,10 +381,9 @@ static int get_chunk_pa(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     int x;
 
     mod->pat = hio_read8(f);
-    mod->trk = mod->pat * mod->chn + 1;	/* Max */
 
-    if (pattern_init(mod) < 0)
-	return -1;
+    if ((mod->xxp = calloc(sizeof (struct xmp_pattern *), mod->pat)) == NULL)
+        return -1;
 
     D_(D_INFO "Stored patterns: %d", mod->pat);
 
@@ -395,10 +412,9 @@ static int get_chunk_p0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     uint16 x16;
 
     mod->pat = hio_read8(f);
-    mod->trk = mod->pat * mod->chn + 1;	/* Max */
 
-    if (pattern_init(mod) < 0)
-	return -1;
+    if ((mod->xxp = calloc(sizeof (struct xmp_pattern *), mod->pat)) == NULL)
+        return -1;
 
     D_(D_INFO "Stored patterns: %d", mod->pat);
 
@@ -424,7 +440,8 @@ static int get_chunk_tr(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     struct xmp_track *track;
 
     mod->trk = hio_read16l(f) + 1;
-    mod->xxt = realloc(mod->xxt, sizeof (struct xmp_track *) * mod->trk);
+    if ((mod->xxt = calloc(sizeof (struct xmp_track *), mod->trk)) == NULL)
+	return -1;
 
     D_(D_INFO "Stored tracks: %d", mod->trk);
 
@@ -445,47 +462,47 @@ static int get_chunk_tr(struct module_data *m, int size, HIO_HANDLE *f, void *pa
             			sizeof (struct xmp_event) * 255);
 
 	for (row = 0; len;) {
+	    struct xmp_event *ev = &track->event[row];
+
 	    j = hio_read8(f);
 	    len--;
 	    switch (j & 0x03) {
 	    case 0:
 		row += j >> 2;
+	        ev = &track->event[row];
 		break;
 	    case 1:
 		for (k = 0; k <= (j >> 2); k++)
-		    memcpy (&track->event[row + k], &track->event[row - 1],
-			sizeof (struct xmp_event));
+		    memcpy (&ev[k], &ev[-1], sizeof (struct xmp_event));
 		row += k - 1;
+	        ev = &track->event[row];
 		break;
 	    case 2:
-		memcpy (&track->event[row], &track->event[j >> 2],
+		memcpy (ev, &track->event[j >> 2],
 		    sizeof (struct xmp_event));
 		break;
 	    case 3:
 		if (j & MDL_NOTE_FOLLOWS) {
 		    uint8 b = hio_read8(f);
 		    len--;
-		    track->event[row].note = b == 0xff ? XMP_KEY_OFF : b + 12;
+		    ev->note = b == 0xff ? XMP_KEY_OFF : b + 12;
 		}
 		if (j & MDL_INSTRUMENT_FOLLOWS)
-		    len--, track->event[row].ins = hio_read8(f);
+		    len--, ev->ins = hio_read8(f);
 		if (j & MDL_VOLUME_FOLLOWS)
-		    len--, track->event[row].vol = hio_read8(f);
+		    len--, ev->vol = hio_read8(f);
 		if (j & MDL_EFFECT_FOLLOWS) {
 		    len--, k = hio_read8(f);
-		    track->event[row].fxt = LSN(k);
-		    track->event[row].f2t = MSN(k);
+		    ev->fxt = LSN(k);
+		    ev->f2t = MSN(k);
 		}
 		if (j & MDL_PARAMETER1_FOLLOWS)
-		    len--, track->event[row].fxp = hio_read8(f);
+		    len--, ev->fxp = hio_read8(f);
 		if (j & MDL_PARAMETER2_FOLLOWS)
-		    len--, track->event[row].f2p = hio_read8(f);
+		    len--, ev->f2p = hio_read8(f);
 		break;
 	    }
 
-	    xlat_fx1(&track->event[row].fxt, &track->event[row].fxp);
-	    xlat_fx2(&track->event[row].f2t, &track->event[row].f2p);
-
 	    row++;
 	}
 
@@ -500,7 +517,15 @@ static int get_chunk_tr(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 
 	memcpy(mod->xxt[i], track, sizeof (struct xmp_track) +
 				sizeof (struct xmp_event) * (row - 1));
+
 	mod->xxt[i]->rows = row;
+
+	/* Translate effects */
+	for (j = 0; j < row; j++) {
+		struct xmp_event *ev = &mod->xxt[i]->event[j];
+		xlat_fx1(&ev->fxt, &ev->fxp);
+		xlat_fx2(&ev->f2t, &ev->f2p);
+	}
     }
 
     free(track);
@@ -572,7 +597,7 @@ static int get_chunk_ii(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 		xxi->rls = x;
 
 	    sub->vra = hio_read8(f);	/* vibrato rate */
-	    sub->vde = hio_read8(f);	/* vibrato delay */
+	    sub->vde = hio_read8(f) >> 1;	/* vibrato depth */
 	    sub->vsw = hio_read8(f);	/* vibrato sweep */
 	    sub->vwf = hio_read8(f);	/* vibrato waveform */
 	    hio_read8(f);		/* Reserved */
@@ -599,8 +624,7 @@ static int get_chunk_is(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     uint8 x;
 
     mod->smp = hio_read8(f);
-    mod->xxs = calloc(sizeof (struct xmp_sample), mod->smp);
-    if (mod->xxs == NULL)
+    if ((mod->xxs = calloc(sizeof (struct xmp_sample), mod->smp)) == NULL)
 	return -1;
 
     data->packinfo = calloc(sizeof (int), mod->smp);
@@ -616,6 +640,7 @@ static int get_chunk_is(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 	hio_read(buf, 1, 32, f);
 	buf[32] = 0;
 	str_adj(buf);
+	strncpy(xxs->name, buf, 32);
 
 	hio_seek(f, 8, SEEK_CUR);		/* Sample filename */
 
@@ -627,8 +652,6 @@ static int get_chunk_is(struct module_data *m, int size, HIO_HANDLE *f, void *pa
 
 	xxs->flg = xxs->lpe > 0 ? XMP_SAMPLE_LOOP : 0;
 	xxs->lpe = xxs->lps + xxs->lpe;
-	if (xxs->lpe > 0)
-	    xxs->lpe--;
 
 	hio_read8(f);				/* Volume in DMDL 0.0 */
 	x = hio_read8(f);
@@ -667,8 +690,7 @@ static int get_chunk_i0(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     if (instrument_init(mod) < 0)
 	return -1;
 
-    data->packinfo = calloc (sizeof (int), mod->smp);
-    if (data->packinfo == NULL)
+    if ((data->packinfo = calloc(sizeof (int), mod->smp)) == NULL)
 	return -1;
 
     for (i = 0; i < mod->ins; i++) {
@@ -728,42 +750,49 @@ static int get_chunk_sa(struct module_data *m, int size, HIO_HANDLE *f, void *pa
     D_(D_INFO "Stored samples: %d", mod->smp);
 
     for (i = 0; i < mod->smp; i++) {
-	int ret;
+	struct xmp_sample *xxs = &mod->xxs[i];
 
-	smpbuf = calloc (1, mod->xxs[i].flg & XMP_SAMPLE_16BIT ?
-		mod->xxs[i].len << 1 : mod->xxs[i].len);
-	if (smpbuf == NULL)
-	    return -1;
+        len = xxs->len;
+	if (xxs->flg & XMP_SAMPLE_16BIT)
+	    len <<= 1;
+
+	if ((smpbuf = calloc(1, len)) == NULL)
+	    goto err;
 
 	switch (data->packinfo[i]) {
 	case 0:
-	    hio_read(smpbuf, 1, mod->xxs[i].len, f);
+	    hio_read(smpbuf, 1, len, f);
 	    break;
 	case 1: 
 	    len = hio_read32l(f);
-	    buf = malloc(len + 4);
+	    if ((buf = malloc(len + 4)) == NULL)
+		goto err2;
 	    hio_read(buf, 1, len, f);
-	    unpack_sample8(smpbuf, buf, len, mod->xxs[i].len);
+	    unpack_sample8(smpbuf, buf, len, xxs->len);
 	    free(buf);
 	    break;
 	case 2:
 	    len = hio_read32l(f);
-	    buf = malloc(len + 4);
+	    if ((buf = malloc(len + 4)) == NULL)
+		goto err2;
 	    hio_read(buf, 1, len, f);
-	    unpack_sample16(smpbuf, buf, len, mod->xxs[i].len);
+	    unpack_sample16(smpbuf, buf, len, xxs->len);
 	    free(buf);
 	    break;
 	}
 	
-	ret = load_sample(m, NULL, SAMPLE_FLAG_NOLOAD,
-					&mod->xxs[i], (char *)smpbuf);
-	free (smpbuf);
+	if (load_sample(m, NULL, SAMPLE_FLAG_NOLOAD, xxs, (char *)smpbuf) < 0)
+	    goto err2;
 
-	if (ret < 0)
-		return -1;
+	free(smpbuf);
     }
 
     return 0;
+
+  err2:
+    free(smpbuf);
+  err:
+    return -1;
 }
 
 static int get_chunk_ve(struct module_data *m, int size, HIO_HANDLE *f, void *parm)
@@ -904,24 +933,21 @@ static int mdl_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
     iff_release(handle);
 
-    /* Re-index instruments & samples */
+    /* Reindex instruments */
+    for (i = 0; i < mod->trk; i++) {
+	for (j = 0; j < mod->xxt[i]->rows; j++) {
+	    struct xmp_event *e = &mod->xxt[i]->event[j];
 
-    for (i = 0; i < mod->pat; i++) {
-	for (j = 0; j < mod->xxp[i]->rows; j++) {
-	    for (k = 0; k < mod->chn; k++) {
-		for (l = 0; l < mod->ins; l++) {
-		    if (j >= mod->xxt[mod->xxp[i]->index[k]]->rows)
-			continue;
-		    
-		    if (EVENT(i, k, j).ins && EVENT(i, k, j).ins == data.i_index[l]) {
-		    	EVENT(i, k, j).ins = l + 1;
-			break;
-		    }
+	    for (l = 0; l < mod->ins; l++) {
+		if (e->ins && e->ins == data.i_index[l]) {
+		    e->ins = l + 1;
+		    break;
 		}
 	    }
 	}
     }
 	
+    /* Reindex envelopes, etc. */
     for (i = 0; i < mod->ins; i++) {
         fix_env(i, &mod->xxi[i].aei, data.v_env, data.v_index, data.v_envnum);
         fix_env(i, &mod->xxi[i].pei, data.p_env, data.p_index, data.p_envnum);
@@ -953,8 +979,8 @@ static int mdl_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
     free(data.packinfo);
 
-    m->quirk |= QUIRKS_FT2;
+    m->quirk |= QUIRKS_FT2 | QUIRK_KEYOFF;
     m->read_event_type = READ_EVENT_FT2;
 
-    return 0;
+    return retval;
 }
