@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -17,7 +17,7 @@ static int mgt_test (HIO_HANDLE *, char *, const int);
 static int mgt_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader mgt_loader = {
-	"Megatracker (MGT)",
+	"Megatracker",
 	mgt_test,
 	mgt_load
 };
