@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -14,7 +14,6 @@
  * - Noisetracker N.T. and M&K! (not tested)
  * - Fast Tracker 6CHN and 8CHN
  * - Fasttracker II/Take Tracker ?CHN and ??CH
- * - M.K. with ADPCM samples (MDZ)
  * - Mod's Grave M.K. w/ 8 channels (WOW)
  * - Atari Octalyser CD61 and CD81
  * - Digital Tracker FA04, FA06 and FA08
@@ -76,7 +75,7 @@ static int mod_test (HIO_HANDLE *, char *, const int);
 static int mod_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader mod_loader = {
-    "Protracker (MOD)",
+    "Amiga Protracker/Compatible",
     mod_test,
     mod_load
 };
@@ -290,7 +289,7 @@ static int mod_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	mod->xxs[i].lpe = mod->xxs[i].lps + 2 * mh.ins[i].loop_size;
 	if (mod->xxs[i].lpe > mod->xxs[i].len)
 		mod->xxs[i].lpe = mod->xxs[i].len;
-	mod->xxs[i].flg = (mh.ins[i].loop_size > 1 && mod->xxs[i].lpe > 8) ?
+	mod->xxs[i].flg = (mh.ins[i].loop_size > 1 && mod->xxs[i].lpe >= 4) ?
 		XMP_SAMPLE_LOOP : 0;
 	mod->xxi[i].sub[0].fin = (int8)(mh.ins[i].finetune << 4);
 	mod->xxi[i].sub[0].vol = mh.ins[i].volume;
@@ -476,17 +475,13 @@ skip_test:
 	ptkloop = 1;
 	break;
     case TRACKER_FASTTRACKER:
-	tracker = "Fast Tracker";
-	break;
     case TRACKER_FASTTRACKER2:
-	tracker = "FastTracker 2";
+    case TRACKER_TAKETRACKER:
+	tracker = "Fast Tracker";
 	break;
     case TRACKER_OCTALYSER:
 	tracker = "Octalyser";
 	break;
-    case TRACKER_TAKETRACKER:
-	tracker = "TakeTracker";
-	break;
     case TRACKER_DIGITALTRACKER:
 	tracker = "Digital Tracker";
 	break;
@@ -497,14 +492,10 @@ skip_test:
 	tracker = "Mod's Grave";
 	break;
     case TRACKER_SCREAMTRACKER3:
-	tracker = "Scream Tracker III";
+	tracker = "Scream Tracker";
 	break;
-    case TRACKER_UNKNOWN_CONV:
-	tracker = "unknown or converted";
 	break;
     case TRACKER_CONVERTEDST:
-	tracker = "converted ST2.2 or earlier";
-	break;
     case TRACKER_CONVERTED:
 	tracker = "converted";
 	break;
@@ -512,14 +503,20 @@ skip_test:
 	tracker = "Protracker clone";
 	break;
     default:
+    case TRACKER_UNKNOWN_CONV:
     case TRACKER_UNKNOWN:
-	tracker = "unknown";
+	tracker = "unknown tracker/converted";
 	break;
     }
 
     mod->trk = mod->chn * mod->pat;
 
-    snprintf(mod->type, XMP_NAME_SIZE, "%s (%s)", tracker, magic);
+    if (!memcmp(magic, "M.K.", 4) || tracker_id == TRACKER_FLEXTRAX) {
+        snprintf(mod->type, XMP_NAME_SIZE, "%s", tracker);
+    } else {
+        snprintf(mod->type, XMP_NAME_SIZE, "%s %s", tracker, magic);
+    }
+
     MODULE_INFO();
 
     for (i = 0; i < mod->ins; i++) {
@@ -561,7 +558,7 @@ skip_test:
 
     /* Load samples */
 
-    if ((x = strrchr(m->filename, '/')))
+    if (m->filename && (x = strrchr(m->filename, '/')))
 	strncpy(pathname, m->filename, x - m->filename);
 
     D_(D_INFO "Stored samples: %d", mod->smp);
