@@ -1,9 +1,23 @@
-/* Extended Module Player
+/* Extended Module Player format loaders
  * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * This file is part of the Extended Module Player and is distributed
- * under the terms of the GNU Lesser General Public License. See COPYING.LIB
- * for more information.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -88,7 +102,6 @@ static int s3m_test(HIO_HANDLE *f, char *t, const int start)
 }
 
 
-
 #define NONE		0xff
 #define FX_S3M_EXTENDED	0xfe
 
@@ -281,7 +294,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
     }
 
     mod->pat = -1;
-    for (i = 0; i < mod->len && mod->xxo[i] < 0xfe; ++i) {
+    for (i = 0; i < mod->len && mod->xxo[i] < 0xff; ++i) {
 	if (mod->xxo[i] > mod->pat)
             mod->pat = mod->xxo[i];
     }
