@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -26,7 +26,7 @@ static int sfx_test (HIO_HANDLE *, char *, const int);
 static int sfx_load (struct module_data *, HIO_HANDLE *, const int);
 
 const struct format_loader sfx_loader = {
-    "SoundFX",
+    "SoundFX v1.3/2.0",
     sfx_test,
     sfx_load
 };
@@ -89,6 +89,9 @@ static int sfx_13_20_load(struct module_data *m, HIO_HANDLE *f, const int nins,
 
     sfx.magic = hio_read32b(f);
     sfx.delay = hio_read16b(f);
+    if (sfx.delay < 178)//min value for 10000bpm
+	return -1;
+
     hio_read(&sfx.unknown, 14, 1, f);
 
     if (sfx.magic != MAGIC_SONG)
