@@ -195,19 +195,7 @@ static int load_patterns(struct module_data *m, int version, HIO_HANDLE *f)
     return 0;
 }
 
-/* Sample number adjustment by Vitamin/CAIG */
-static struct xmp_sample* realloc_samples(struct xmp_sample* buf, int* size, int new_size)
-{
-  buf = realloc(buf, sizeof (struct xmp_sample) * new_size);
-  if (buf == NULL)
-    return NULL;
-  if (new_size > *size)
-    memset(buf + *size, 0, sizeof (struct xmp_sample) * (new_size - *size));
-  *size = new_size;
-  return buf;
-}
-
-//packed structures size
+/* Packed structures size */
 #define XM_INST_HEADER_SIZE 33
 #define XM_INST_SIZE 208
 
@@ -300,7 +288,7 @@ static int load_instruments(struct module_data *m, int version, HIO_HANDLE *f)
 		hio_seek(f, (int)xih.size - (XM_INST_HEADER_SIZE + XM_INST_SIZE), SEEK_CUR);
 
 		/* Envelope */
-		xxi->rls = xi.v_fade;
+		xxi->rls = xi.v_fade << 1;
 		xxi->aei.npt = xi.v_pts;
 		xxi->aei.sus = xi.v_sus;
 		xxi->aei.lps = xi.v_start;
