@@ -448,7 +448,10 @@ void mixer_softmixer(struct context_data *ctx)
 	if (~s->format & XMP_FORMAT_MONO) {
 		size *= 2;
 	}
-	assert(size <= XMP_MAX_FRAMESIZE);
+
+	if (size > XMP_MAX_FRAMESIZE) {
+		size = XMP_MAX_FRAMESIZE;
+	}
 
 	if (s->format & XMP_FORMAT_8BIT) {
 		downmix_int_8bit(s->buffer, s->buf32, size, s->amplify,
@@ -613,7 +616,6 @@ void mixer_setvol(struct context_data *ctx, int voc, int vol)
 void mixer_seteffect(struct context_data *ctx, int voc, int type, int val)
 {
 	struct player_data *p = &ctx->p;
-	struct module_data *m = &ctx->m;
 	struct mixer_voice *vi = &p->virt.voice_array[voc];
 
 	switch (type) {
@@ -633,10 +635,6 @@ void mixer_seteffect(struct context_data *ctx, int voc, int type, int val)
 		vi->filter.b1 = val;
 		break;
 	}
-
-	if (vi->fidx & FLAG_SYNTH) {
-		m->synth->seteffect(ctx, voc, type, val);
-	}
 }
 
 void mixer_setpan(struct context_data *ctx, int voc, int pan)
