@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -73,15 +73,20 @@ int period_to_note(int p)
 }
 
 
-/* Get pitchbend from base note and period */
+/* Get pitchbend from base note and amiga period */
 int period_to_bend(double p, int n, int limit, int gliss, int type)
 {
     int b;
     double d;
 
-    if (!n)
+    if (n == 0)
 	return 0;
 
+    if (type) {
+    	b = 100 * (8 * (((240 - n) << 4) - p));	/* Linear */
+    	return gliss ? b / 12800 * 12800 : b;
+    }
+
     if (limit) {				/* Force Amiga limits */
 	if (p > AMIGA_LIMIT_LOWER)
 	    p = AMIGA_LIMIT_LOWER;
@@ -89,11 +94,6 @@ int period_to_bend(double p, int n, int limit, int gliss, int type)
 	    p = AMIGA_LIMIT_UPPER;
     }
 
-    if (type) {
-	b = 100 * (8 * (((240 - n) << 4) - p));	/* Linear */
-	return gliss ? b / 12800 * 12800 : b;
-    }
-
     if (p < MIN_PERIOD_A)
 	p = MIN_PERIOD_A;
 
