@@ -1,5 +1,5 @@
 /* Extended Module Player
- * Copyright (C) 1996-2013 Claudio Matsuoka and Hipolito Carraro Jr.
+ * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr.
  *
  * This file is part of the Extended Module Player and is distributed
  * under the terms of the GNU Lesser General Public License. See COPYING.LIB
@@ -296,7 +296,7 @@ void virt_setsmp(struct context_data *ctx, int chn, int smp)
 	mixer_voicepos(ctx, voc, pos, frac);	/* Restore old position */
 }
 
-static inline void check_dct(struct context_data *ctx, int i, int chn, int ins,
+static void check_dct(struct context_data *ctx, int i, int chn, int ins,
 			int smp, int note, int dct, int dca)
 {
 	struct player_data *p = &ctx->p;
