@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "md5.h"
 #include "xmp.h"
 
 static inline int is_big_endian() {
@@ -22,15 +23,35 @@ static void convert_endian(unsigned char *p, int l)
 	}
 }
 
+static int compare_md5(unsigned char *d, char *digest)
+{
+	int i;
+
+	/*for (i = 0; i < 16 ; i++)
+		printf("%02x", d[i]);
+	printf("\n");*/
+
+	for (i = 0; i < 16 && *digest; i++, digest += 2) {
+		char hex[3];
+		hex[0] = digest[0];
+		hex[1] = digest[1];
+		hex[2] = 0;
+
+		if (d[i] != strtoul(hex, NULL, 16))
+			return -1;
+	}
+
+	return 0;
+}
 
 int main()
 {
-	FILE *f;
 	int ret;
-	unsigned char *buf;
 	xmp_context c;
 	struct xmp_frame_info info;
 	long time;
+	unsigned char digest[16];
+	MD5_CTX ctx;
 
 	c = xmp_create_context();
 	if (c == NULL)
@@ -52,22 +73,12 @@ int main()
 	xmp_set_player(c, XMP_PLAYER_MIX, 100);
 	xmp_set_player(c, XMP_PLAYER_INTERP, XMP_INTERP_SPLINE);
 
-	f = fopen("test.raw", "rb");
-	if (f == NULL) {
-		printf("can't open raw data file\n");
-		goto err;
-	}
-
-	buf = malloc(XMP_MAX_FRAMESIZE);
-	if (buf == NULL) {
-		printf("can't alloc raw buffer\n");
-		goto err;
-	}
-
 	printf("Testing ");
 	fflush(stdout);
 	time = 0;
 
+	MD5Init(&ctx);
+
 	while (1) {
 		xmp_play_frame(c);
 		xmp_get_frame_info(c, &info);
@@ -76,32 +87,27 @@ int main()
 
 		time += info.frame_time;
 
-		ret = fread(buf, 1, info.buffer_size, f);
-
 		if (is_big_endian())
-			convert_endian(buf, info.buffer_size >> 1);
+			convert_endian(info.buffer, info.buffer_size >> 1);
 
-		if (ret != info.buffer_size) {
-			printf("error reading raw buffer\n");
-			goto err;
-		}
-
-		if (memcmp(buf, info.buffer, info.buffer_size) != 0) {
-			printf("replay error\n");
-			goto err;
-		}
+		MD5Update(&ctx, info.buffer, info.buffer_size);
 
 		printf(".");
 		fflush(stdout);
 	}
 
+	MD5Final(digest, &ctx);
+
+	if (compare_md5(digest, "7e39451c7e14938c41b146eb23943056") < 0) {
+		printf("rendering error\n");
+		goto err;
+	}
+
 	if (time / 1000 != info.total_time) {
 		printf("replay time error\n");
 		goto err;
 	}
 
-	fclose(f);
-
 	printf(" pass\n");
 
 	exit(0);
